pub struct PanelStorage {
pub id: RustConstructorId,
pub ignore_render_layer: bool,
pub hidden: bool,
}Expand description
Storage structure for panel resource metadata.
面板资源元数据的存储结构。
This struct holds essential information about resources stored within panels, including visibility, rendering behavior, and sizing information.
该结构体保存面板内存储资源的基本信息,包括可见性、渲染行为和尺寸信息。
Fields
id: RustConstructorIdUnique identifier for the stored resource.
存储资源的唯一标识符。
ignore_render_layer: boolIf true, the resource ignores render layer.
如果为true,则资源忽略渲染层。
Controls whether the resource is visible.
控制资源是否可见。