Module background

Module background 

This file contains backend resources, which can store some key data and be called upon when needed.

此文件包含后端资源,后端资源可以存储一些关键数据并在有需要时调用。

Structs

Font
Font resource for text rendering.
PageData
Storage Rust Constructor resource for page-specific data and state management.
SplitTime
Time segmentation resource for tracking and managing timing information.
Variable
Generic variable resource for storing any type of data with metadata.
WrapDefinitions
A structure used to wrap font definitions.