Module basic_front

Module basic_front 

This file contains basic front resources. Basic front resources can be used independently or to create advanced front-end resources.

此文件包含基本前端资源。基本前端资源可以单独使用,也可被用于创建高级前端资源。

Structs

CustomRect
Custom rectangle resource for drawing rectangles with various visual properties.
CustomRectConfig
Config options for custom rectangles.
DebugTextureHandle
Wrapper for TextureHandle that supports Debug trait derivation.
Image
Image resource for displaying graphical content in the GUI.
ImageConfig
Config options for image resources.
Text
Text resource for displaying and interacting with textual content.
TextConfig
Config options for text resources.

Enums

HyperlinkSelectMethod
Control the selection method of hyperlinks.
ImageLoadMethod
Methods for loading images into the resource.