LoadedImageData

Struct LoadedImageData 

pub struct LoadedImageData {
    pub color_image: ColorImage,
}
Request sent to the background worker thread to load an image from disk.

发送到后台工作线程的图片加载请求。 Result returned from the background worker thread after loading an image.

后台工作线程完成图片加载后返回的结果。

Fields

color_image: ColorImage

Decoded image data ready for texture upload on the main thread.

已解码的图像数据,可在主线程直接上传为纹理。