This file contains basic front resources. Basic front resources can be used independently or to create advanced front-end resources.
此文件包含基本前端资源。基本前端资源可以单独使用,也可被用于创建高级前端资源。
Structs
- Custom
Rect - Custom rectangle resource for drawing rectangles with various visual properties.
- Custom
Rect Config - Config options for custom rectangles.
- Debug
Texture Handle - Wrapper for TextureHandle that supports Debug trait derivation.
- Image
- Image resource for displaying graphical content in the GUI.
- Image
Config - Config options for image resources.
- Text
- Text resource for displaying and interacting with textual content.
- Text
Config - Config options for text resources.
Enums
- Hyperlink
Select Method - Control the selection method of hyperlinks.
- Image
Load Method - Methods for loading images into the resource.