pub struct ImageLoader {
pub completed: Arc<Mutex<HashMap<String, LoadedImageData>>>,
}Expand description
Manages the background image loading infrastructure.
管理后台图片加载基础设施。
Fields
completed: Arc<Mutex<HashMap<String, LoadedImageData>>>Completed loads from worker threads, keyed by resource name. Each frame, completed loads are drained to create egui textures.
工作线程完成的加载结果,按资源名称索引。每帧消耗以创建 egui 纹理。