pub struct Text {Show 21 fields
pub basic_front_resource_config: BasicFrontResourceConfig,
pub position: [f32; 2],
pub size: [f32; 2],
pub display_info: DisplayInfo,
pub content: String,
pub font_size: f32,
pub color: [u8; 3],
pub alpha: u8,
pub background_color: [u8; 3],
pub background_alpha: u8,
pub background_rounding: f32,
pub font: String,
pub selectable: bool,
pub hyperlink_text: Vec<(String, HyperlinkSelectMethod)>,
pub hyperlink_index: Vec<(usize, usize, String)>,
pub auto_fit: [bool; 2],
pub last_frame_content: String,
pub selection: Option<(usize, usize)>,
pub truncate_size: [f32; 2],
pub actual_size: [f32; 2],
pub tags: Vec<[String; 2]>,
}Expand description
Text resource for displaying and interacting with textual content.
用于显示和交互文本内容的文本资源。
Fields
basic_front_resource_config: BasicFrontResourceConfigConfig for basic front resource properties.
基本前端资源属性配置。
position: [f32; 2]Current display position of the text as [x, y].
文本的当前显示位置,坐标为[x, y]。
size: [f32; 2]Current display size of the text as [width, height].
文本的当前显示尺寸,为[width, height]。
display_info: DisplayInfoDisplay info controlling visibility and rendering.
显示信息,控制可见性和渲染。
content: StringText content to be displayed.
要显示的文本内容。
font_size: f32Font size in points.
字体大小(点)。
color: [u8; 3]Text color as [R, G, B].
文本颜色,格式为[R, G, B]。
alpha: u8Opacity of the text (0-255).
文本的不透明度(0-255)。
background_color: [u8; 3]Background color behind the text as [R, G, B].
文本背后的背景颜色,格式为[R, G, B]。
background_alpha: u8Opacity of the background (0-255).
背景的不透明度(0-255)。
background_rounding: f32Radius for rounded corners of the background.
背景圆角半径。
font: StringThe font used for the specified text.
指定文本使用的字体。
selectable: boolWhether the text can be selected by the user.
文本是否可以被用户选择。
hyperlink_text: Vec<(String, HyperlinkSelectMethod)>Hyperlink texts with their selection methods for clickable regions.
可点击区域的超链接文本及其选择方法。
hyperlink_index: Vec<(usize, usize, String)>Hyperlink indices and URLs: (start_index, end_index, url).
超链接索引值和链接:(起始索引, 结束索引, 链接)。
auto_fit: [bool; 2]Auto-fit behavior: [horizontal_fit, vertical_fit].
是否让渲染层大小自动匹配实际大小:[水平适应, 垂直适应]。
last_frame_content: StringText content from the previous frame for change detection.
上一帧的文本内容,用于变化检测。
selection: Option<(usize, usize)>Currently selected text range (start_index, end_index).
框选选中的文本范围(起始索引, 结束索引)。
truncate_size: [f32; 2]Size at which text is truncated for display.
文本被截断以供显示的尺寸。
actual_size: [f32; 2]Actual size of the text content.
文本内容的实际尺寸。
Key-value pairs for categorization and metadata.
用于分类和元数据的键值对标签。
Implementations
Sourceimpl Text
impl Text
pub fn from_config(self, config: &TextConfig) -> Self
pub fn basic_front_resource_config( self, basic_front_resource_config: &BasicFrontResourceConfig, ) -> Self
pub fn ignore_render_layer(self, ignore_render_layer: bool) -> Self
pub fn content(self, content: &str) -> Self
pub fn font_size(self, font_size: f32) -> Self
pub fn color(self, r: u8, g: u8, b: u8) -> Self
pub fn alpha(self, alpha: u8) -> Self
pub fn background_color(self, r: u8, g: u8, b: u8) -> Self
pub fn background_alpha(self, alpha: u8) -> Self
pub fn background_rounding(self, background_rounding: f32) -> Self
pub fn font(self, font: &str) -> Self
pub fn selectable(self, selectable: bool) -> Self
pub fn push_hyperlink_text( self, target_text: &str, select_method: HyperlinkSelectMethod, ) -> Self
pub fn hyperlink_text( self, hyperlink_text: Vec<(String, HyperlinkSelectMethod)>, ) -> Self
pub fn auto_fit(self, x: bool, y: bool) -> Self