BasicFrontResourceConfig

Struct BasicFrontResourceConfig 

pub struct BasicFrontResourceConfig {
    pub position_size_config: PositionSizeConfig,
    pub clip_rect: Option<PositionSizeConfig>,
}
Config for basic front resources.

基本前端资源的配置。

This struct contains all the essential config needed for positioning, sizing, and clipping visual elements in the GUI.

这个结构体包含了在GUI中定位、调整大小和裁剪可视元素所需的所有配置。

Fields

position_size_config: PositionSizeConfig

Config for position, size, and layout properties.

位置、大小和布局属性的配置。

clip_rect: Option<PositionSizeConfig>

Optional clipping rectangle that defines the visible area. If None, the resource is rendered without clipping.

可选的裁剪矩形,用于定义可见区域。如果为None,则渲染资源时不进行裁剪。

Implementations

Source

impl BasicFrontResourceConfig

pub fn position_size_config( self, position_size_config: PositionSizeConfig, ) -> Self

pub fn clip_rect(self, clip_rect: Option<PositionSizeConfig>) -> Self